@@ -14,7 +14,9 @@ from .constants import (
     SCRIBE_PRODUCTS_DATASET,
     SCRIBE_POLICY_DATASET,
     SCRIBE_TEAM_STAT_DATASET,
-    SCRIBE_LINEAGE_DATASET
+    SCRIBE_LINEAGE_DATASET,
+    SCRIBE_RISK_DATASET,
+    SCRIBE_FINDINGS_DATASET
 )
 
 class ScribeClient:
@@ -23,6 +25,8 @@ class ScribeClient:
     scribe_policy_dataset = SCRIBE_POLICY_DATASET
     scribe_team_stat_dataset = SCRIBE_TEAM_STAT_DATASET
     scribe_lineage_dataset=SCRIBE_LINEAGE_DATASET
+    scribe_risk_dataset = SCRIBE_RISK_DATASET
+    scribe_findings_dataset = SCRIBE_FINDINGS_DATASET
 
     def get_chache_data(self):
         return {
@@ -43,7 +47,7 @@ class ScribeClient:
                 return True
             return (datetime.datetime.now() - last_update).days > 1
 
-    def __init__(self, api_token=None, ignore_env = False, base_url="https://api.scribesecurity.com", refresh_interval=600, cached_data={}):
+    def __init__(self, api_token=None, ignore_env = False, base_url="https://api.scribesecurity.com", refresh_interval=600, cached_data={}, env = "prod"):
         def update_from_cached_data(cached_data):
             if "datasets" in cached_data:
                 self.datasets = cached_data["datasets"]
@@ -71,7 +75,7 @@ class ScribeClient:
         if not self.api_token:
             logging.error("No API token provided. Please set the SCRIBE_TOKEN environment variable or pass it as an argument.")
             return
-        
+        self.env = env
         self.base_url = base_url
         self.refresh_interval = refresh_interval
         self.last_refresh = datetime.datetime.now() - datetime.timedelta(days=5)  # Initialize to a time in the past
@@ -161,7 +165,8 @@ class ScribeClient:
             return
         jwt_name = decoded_token.get("name")
         try:
-            self.team_id = jwt_name.split("scribe-hub-team")[1].split("-")[0]
+            prefix = "scribe-hub-team" if self.env == "prod" else f"scribe-hub-{self.env}-team"
+            self.team_id = jwt_name.split(prefix)[1].split("-")[0]
             logging.info(f"Team:{self.team_id}")
         except Exception as e:
             logging.error(f"Error extracting team ID: {e}")
@@ -1062,4 +1067,22 @@ class ScribeClient:
             r = self.query_superset(self.scribe_policy_dataset, query, time_tokens=["time_evaluated"])
             if r:
                 return f"{title}\n{self.format_query_result_table(r)}"
+        return "Error running query"
+    
+    def query_risk(self, querystr, title="") -> str:
+        logging.debug(f"Query risk table with: {querystr}")
+        query = self.querystr_to_json(querystr)
+        if query:
+            r = self.query_superset(self.scribe_risk_dataset, query, time_tokens=["timestamp"])
+            if r:
+                return f"{title}\n{self.format_query_result_table(r)}"
+        return "Error running query"
+    
+    def query_findings(self, querystr, title="") -> str:
+        logging.debug(f"Query finding table with: {querystr}")
+        query = self.querystr_to_json(querystr)
+        if query:
+            r = self.query_superset(self.scribe_findings_dataset, query, time_tokens=["timestamp"])
+            if r:
+                return f"{title}\n{self.format_query_result_table(r)}"
         return "Error running query"
\ No newline at end of file
